@@ -3,8 +3,7 @@
 #' The \code{plot()} method for the \code{performance::check_normality()} function.
 #'
 #' @param type Character vector, indicating the type of plot.
-#' @param size Size of geoms. Depends on the context of the \code{plot()} function,
-#'   so this argument may change size of points, lines or bars.
+#' @param size_line Size of line geoms.
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
 #'
@@ -18,7 +17,7 @@
 #' @importFrom bayestestR estimate_density
 #' @importFrom stats residuals sd dnorm rstudent ppoints pnorm fitted
 #' @export
-plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data = NULL, size = .8, point_size = 2, ...) {
+plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data = NULL, size_line = .8, size_point = 2, ...) {
   type <- match.arg(type)
 
   if (is.null(data)) {
@@ -29,7 +28,7 @@ plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data =
 
   # check type
   if (!is.null(attributes(x)$effects) && attributes(x)$effects == "random") {
-    .plot_diag_reqq(attributes(x)$re_qq, point_size = point_size, line_size = size)
+    .plot_diag_reqq(attributes(x)$re_qq, size_point = size_point, size_line = size_line)
   } else {
     if (type == "qq") {
       if (inherits(model, c("lme", "lmerMod", "merMod", "glmmTMB"))) {
@@ -40,7 +39,7 @@ plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data =
 
       fitted_ <- sort(stats::fitted(model), na.last = NA)
       dat <- stats::na.omit(data.frame(x = fitted_, y = res_))
-      .plot_diag_qq(dat, point_size = point_size, line_size = size)
+      .plot_diag_qq(dat, size_point = size_point, size_line = size_line)
     } else if (type == "density") {
       r <- stats::residuals(model)
       dat <- as.data.frame(bayestestR::estimate_density(r))
@@ -49,7 +48,7 @@ plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data =
         mean(r),
         stats::sd(r)
       )
-      .plot_diag_norm(dat, line_size = size)
+      .plot_diag_norm(dat, size_line = size_line)
     } else if (type == "pp") {
       if (!requireNamespace("MASS", quietly = TRUE)) {
         stop("Package 'MASS' required for PP-plots. Please install it.", call. = FALSE)
@@ -59,7 +58,7 @@ plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data =
       dparms <- MASS::fitdistr(x, densfun = "normal")
       y <- do.call(stats::pnorm, c(list(q = x), dparms$estimate))
       dat <- data.frame(x = probs, y = y)
-      .plot_diag_pp(dat, point_size = point_size, line_size = size)
+      .plot_diag_pp(dat, size_point = size_point, size_line = size_line)
     }
   }
 }
